@@ -588,7 +588,7 @@ class OMFITGPECcoils(OMFITcoils):
 
             # fill in all the info needed for a coil file
             coils = self
-            coils['periods'] = 1
+            coils['periods'] = s  # this isn't really right, but we need somewhere to store the info
             coils['num_coils'] = ncoil
             nc = 0
             for i in range(ncoil):
@@ -613,7 +613,7 @@ class OMFITGPECcoils(OMFITcoils):
         with open(self.filename, 'w') as f:
             # write the defining parameters
             ncoil = self['num_coils']
-            s = 1  # have to assume this?
+            s = self['periods']  # hack storing this info here
             nsec = len(self[list(self.keys())[-1]]['x'])
             nw = self[list(self.keys())[-1]]['I']
             if nsec < 1e4:
@@ -643,4 +643,8 @@ class OMFITGPECcoils(OMFITcoils):
         result = OMFITcoils(filename)
         result.update(self)
 
+        # convert from gpec convention of coils with sections to standard individual coils convention
+        self['num_coils'] = self['num_coils'] * self['periods']
+        coils['periods'] = 1  # remove hack where gpec stores it's info about coil sections
+
         return result
