@@ -1086,7 +1086,7 @@ else:
                     self['neo_files'][k] = self[k]
                     del self[k]
 
-    def copy_gacode_module_settings(root):
+    def copy_gacode_module_settings(root=None):
         """
         Utility function to sync all GACODE modules to use the same working environment
 
@@ -1096,36 +1096,17 @@ else:
 
         default_GACODE_branch = OMFITexpression(
             '''
-version = '2022.17'
 server = root['SETTINGS']['REMOTE_SETUP']['serverPicker']
 if is_server(server, ['iris', 'saturn']):
-    if version == 'pre_pygacode':
-        return_variable = '/dev'
-    elif version=='post_pygacode':
-        return_variable = '/pygacode'
-    elif version=='tglf_sat2':
-        return_variable = '/tglf_sat2'
-    elif version=='2022.17':
-        return_variable = '/2022.17'
+    return_variable = '/2022.17'
 elif is_server(server, ['omega']):
     return_variable = '/2022.17'
 elif is_server(server, 'portal'):
-    if version == 'pre_pygacode':
-        return_variable = '/unstable'
-    elif version == 'post_pygacde':
-        return_variable = '/pygacode'
-    else:
-        return_variable = 'gacode'
+    return_variable = 'gacode'
 elif is_server(server, 'cori'):
-    if version == 'pre_pygacode':
-        raise ValueError(f'GACODE installation on {server} has not yet been updated to pre_gacode')
-    else:
-        return_variable = ''
+    return_variable = ''
 else:
-    if version == 'pre_pygacode':
-        return_variable = ''
-    else:
-        raise ValueError(f'GACODE installation on {server} has not yet been updated to post_gacode')
+    raise ValueError(f'GACODE installation on {server} has not yet been updated to post_gacode')
     '''.strip()
         )
 
