@@ -1299,6 +1299,8 @@ def server_picker(root, MainSettings):
         server_picker_cache[device] = 'omega'
     elif is_localhost(['pppl_sunfire', 'nx', 'portal', 'sunfire'], looseCheck=True):
         server_picker_cache[device] = 'portal'
+    elif is_localhost(['shenma', 'login110', 'login111', 'login112', 'login113']):
+        server_picker_cache[device] = 'shenma'
     else:
         # The decision for server is device dependent
         if is_device(experiment_branch['device'], 'DIII-D') and MainSettings['SERVER']['GA_username']:
